==> moserial-2.26.2.tar.bz2: moserial-2.26.2/src/SendChooserDialog.h <==

#ifndef __SRC_SENDCHOOSERDIALOG_H__
#define __SRC_SENDCHOOSERDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define MOSERIAL_TYPE_SEND_CHOOSER_DIALOG (moserial_send_chooser_dialog_get_type ())
#define MOSERIAL_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialog))
#define MOSERIAL_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))
#define MOSERIAL_IS_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
#define MOSERIAL_IS_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
#define MOSERIAL_SEND_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))

typedef struct _moserialSendChooserDialog moserialSendChooserDialog;
typedef struct _moserialSendChooserDialogClass moserialSendChooserDialogClass;
typedef struct _moserialSendChooserDialogPrivate moserialSendChooserDialogPrivate;

struct _moserialSendChooserDialog {
	GObject parent_instance;
	moserialSendChooserDialogPrivate * priv;
	GtkComboBox* protocolCombo;
	char* filename;
};

struct _moserialSendChooserDialogClass {
	GObjectClass parent_class;
};


moserialSendChooserDialog* moserial_send_chooser_dialog_construct (GType object_type, GtkBuilder* builder);
moserialSendChooserDialog* moserial_send_chooser_dialog_new (GtkBuilder* builder);
void moserial_send_chooser_dialog_show (moserialSendChooserDialog* self, const char* folder);
gboolean moserial_send_chooser_dialog_hide (moserialSendChooserDialog* self, GtkWidget* w);
GtkBuilder* moserial_send_chooser_dialog_get_builder (moserialSendChooserDialog* self);
GType moserial_send_chooser_dialog_get_type (void);


G_END_DECLS

#endif

==> moserial-2.27.5.tar.bz2: moserial-2.27.5/src/SendChooserDialog.h <==

#ifndef __SRC_SENDCHOOSERDIALOG_H__
#define __SRC_SENDCHOOSERDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define MOSERIAL_TYPE_SEND_CHOOSER_DIALOG (moserial_send_chooser_dialog_get_type ())
#define MOSERIAL_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialog))
#define MOSERIAL_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))
#define MOSERIAL_IS_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
#define MOSERIAL_IS_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
#define MOSERIAL_SEND_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))

typedef struct _moserialSendChooserDialog moserialSendChooserDialog;
typedef struct _moserialSendChooserDialogClass moserialSendChooserDialogClass;
typedef struct _moserialSendChooserDialogPrivate moserialSendChooserDialogPrivate;

struct _moserialSendChooserDialog {
	GObject parent_instance;
	moserialSendChooserDialogPrivate * priv;
	GtkComboBox* protocolCombo;
	char* filename;
};

struct _moserialSendChooserDialogClass {
	GObjectClass parent_class;
};


moserialSendChooserDialog* moserial_send_chooser_dialog_construct (GType object_type, GtkBuilder* builder);
moserialSendChooserDialog* moserial_send_chooser_dialog_new (GtkBuilder* builder);
void moserial_send_chooser_dialog_show (moserialSendChooserDialog* self, const char* folder);
gboolean moserial_send_chooser_dialog_hide (moserialSendChooserDialog* self);
GtkBuilder* moserial_send_chooser_dialog_get_builder (moserialSendChooserDialog* self);
GType moserial_send_chooser_dialog_get_type (void);


G_END_DECLS

#endif
